# Repositories

Total Count: {{ count }}

|Name|URL|Language|Description|
|:--:|:--:|:--:|:--|
{%- for repo in repositories %}
|{{ repo.name }}{% if repo.is_archive %} ![archived](https://img.shields.io/badge/archived-red.svg){% endif %}{% if repo.is_template %} ![template](https://img.shields.io/badge/template-green.svg){% endif %}|{{ repo.url }}|{% if repo.language_logo_url %}![{{ repo.language }}]({{ repo.language_logo_url }}){% else %}{{ repo.language if repo.language is not none else '' }}{% endif %}|{{ repo.description if repo.description is not none else '' }}|
{%- endfor %}

> Generated by [ghc](https://github.com/homoluctus/ghc)
